# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSPMessages.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSPMessages.proto',
  package='TSP',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x11TSPMessages.proto\x12\x03TSP\"X\n\tReference\x12\x12\n\nidentifier\x18\x01 \x02(\x04\x12\x17\n\x0f\x64\x65precated_type\x18\x02 \x01(\x05\x12\x1e\n\x16\x64\x65precated_is_external\x18\x03 \x01(\x08\"#\n\rDataReference\x12\x12\n\nidentifier\x18\x01 \x02(\x04\"\x92\x01\n\x14SparseReferenceArray\x12\r\n\x05\x63ount\x18\x01 \x02(\r\x12\x30\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1f.TSP.SparseReferenceArray.Entry\x1a\x39\n\x05\x45ntry\x12\r\n\x05index\x18\x01 \x02(\r\x12!\n\treference\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"\x1d\n\x05Point\x12\t\n\x01x\x18\x01 \x02(\x02\x12\t\n\x01y\x18\x02 \x02(\x02\"%\n\x04Size\x12\r\n\x05width\x18\x01 \x02(\x02\x12\x0e\n\x06height\x18\x02 \x02(\x02\")\n\x05Range\x12\x10\n\x08location\x18\x01 \x02(\r\x12\x0e\n\x06length\x18\x02 \x02(\r\"\x17\n\x04\x44\x61te\x12\x0f\n\x07seconds\x18\x01 \x02(\x01\"&\n\x08IndexSet\x12\x1a\n\x06ranges\x18\x01 \x03(\x0b\x32\n.TSP.Range\"\x8e\x02\n\x05\x43olor\x12$\n\x05model\x18\x01 \x02(\x0e\x32\x15.TSP.Color.ColorModel\x12\t\n\x01r\x18\x03 \x01(\x02\x12\t\n\x01g\x18\x04 \x01(\x02\x12\t\n\x01\x62\x18\x05 \x01(\x02\x12*\n\x08rgbspace\x18\x0c \x01(\x0e\x32\x18.TSP.Color.RGBColorSpace\x12\x0c\n\x01\x61\x18\x06 \x01(\x02:\x01\x31\x12\t\n\x01\x63\x18\x07 \x01(\x02\x12\t\n\x01m\x18\x08 \x01(\x02\x12\t\n\x01y\x18\t \x01(\x02\x12\t\n\x01k\x18\n \x01(\x02\x12\t\n\x01w\x18\x0b \x01(\x02\"*\n\nColorModel\x12\x07\n\x03rgb\x10\x01\x12\x08\n\x04\x63myk\x10\x02\x12\t\n\x05white\x10\x03\"!\n\rRGBColorSpace\x12\x08\n\x04srgb\x10\x01\x12\x06\n\x02p3\x10\x02\"\xce\x01\n\x04Path\x12#\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x11.TSP.Path.Element\x1aJ\n\x07\x45lement\x12#\n\x04type\x18\x01 \x02(\x0e\x32\x15.TSP.Path.ElementType\x12\x1a\n\x06points\x18\x02 \x03(\x0b\x32\n.TSP.Point\"U\n\x0b\x45lementType\x12\n\n\x06moveTo\x10\x01\x12\n\n\x06lineTo\x10\x02\x12\x0f\n\x0bquadCurveTo\x10\x03\x12\x0b\n\x07\x63urveTo\x10\x04\x12\x10\n\x0c\x63loseSubpath\x10\x05\"\x8b\x01\n\x13ReferenceDictionary\x12/\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x1e.TSP.ReferenceDictionary.Entry\x1a\x43\n\x05\x45ntry\x12\x1b\n\x03key\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05value\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"$\n\x04UUID\x12\r\n\x05lower\x18\x01 \x02(\x04\x12\r\n\x05upper\x18\x02 \x02(\x04\"g\n\rCFUUIDArchive\x12\x12\n\nuuid_bytes\x18\x01 \x01(\x0c\x12\x0f\n\x07uuid_w0\x18\x02 \x01(\r\x12\x0f\n\x07uuid_w1\x18\x03 \x01(\r\x12\x0f\n\x07uuid_w2\x18\x04 \x01(\r\x12\x0f\n\x07uuid_w3\x18\x05 \x01(\r\")\n\x0eUUIDSetArchive\x12\x17\n\x04uids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\"F\n\x0eUUIDMapArchive\x12\x19\n\x06source\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x19\n\x06target\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"K\n\x13UUIDMultiMapArchive\x12\x19\n\x06source\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x19\n\x06target\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"M\n\x10UUIDCoordArchive\x12\x1a\n\x07row_uid\x18\x01 \x02(\x0b\x32\t.TSP.UUID\x12\x1d\n\ncolumn_uid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\"N\n\x0fUUIDRectArchive\x12\x1e\n\x0b\x63olumn_uids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\x12\x1b\n\x08row_uids\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"~\n\x0fSparseUUIDArray\x12\r\n\x05\x63ount\x18\x01 \x02(\r\x12+\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1a.TSP.SparseUUIDArray.Entry\x1a/\n\x05\x45ntry\x12\r\n\x05index\x18\x01 \x02(\r\x12\x17\n\x04uuid\x18\x02 \x02(\x0b\x32\t.TSP.UUID\"$\n\x08UUIDPath\x12\x18\n\x05uuids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\"\x8f\x01\n\x13SparseUUIDPathArray\x12\r\n\x05\x63ount\x18\x01 \x02(\r\x12/\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1e.TSP.SparseUUIDPathArray.Entry\x1a\x38\n\x05\x45ntry\x12\r\n\x05index\x18\x01 \x02(\r\x12 \n\tuuid_path\x18\x02 \x02(\x0b\x32\r.TSP.UUIDPath\"\x9a\x03\n\x10PasteboardObject\x12\"\n\nstylesheet\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\tdrawables\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06styles\x18\x03 \x03(\x0b\x32\x0e.TSP.Reference\x12\"\n\nwp_storage\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rguide_storage\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12)\n\x11\x61pp_native_object\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x0fis_text_primary\x18\x07 \x01(\x08\x12\x10\n\x08is_smart\x18\x08 \x01(\x08\x12\x1f\n\x07presets\x18\n \x03(\x0b\x32\x0e.TSP.Reference\x12)\n\x11top_level_objects\x18\x0b \x03(\x0b\x32\x0e.TSP.Reference\x12\x32\n\x1anative_content_description\x18\x0c \x01(\x0b\x32\x0e.TSP.Reference\"3\n\x10ObjectCollection\x12\x1f\n\x07objects\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\"F\n\x0fObjectContainer\x12\x12\n\nidentifier\x18\x01 \x01(\r\x12\x1f\n\x07objects\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\x1a\n\x0e\x44\x61taAttributes*\x08\x08\x64\x10\x80\x80\x80\x80\x02\"p\n\x11LargeArraySegment\x12\x1e\n\x16should_delay_archiving\x18\x01 \x01(\x08\x12\"\n\x1a\x64\x65layed_archiving_priority\x18\x02 \x01(\r\x12\x17\n\x0fpackage_locator\x18\x03 \x01(\t\"`\n\x17LargeNumberArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12\x10\n\x08\x65lements\x18\x02 \x03(\x01\"\xb2\x01\n\x17LargeStringArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12>\n\x08\x65lements\x18\x02 \x03(\x0b\x32,.TSP.LargeStringArraySegment.OptionalElement\x1a\"\n\x0fOptionalElement\x12\x0f\n\x07\x65lement\x18\x01 \x01(\t\"i\n\x15LargeUUIDArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12\x1b\n\x08\x65lements\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"t\n\x1bLargeLazyObjectArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12 \n\x08\x65lements\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"p\n\x17LargeObjectArraySegment\x12\x33\n\x13large_array_segment\x18\x01 \x01(\x0b\x32\x16.TSP.LargeArraySegment\x12 \n\x08\x65lements\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\"\x8e\x02\n\nLargeArray\x12\x1a\n\x06ranges\x18\x01 \x03(\x0b\x32\n.TSP.Range\x12 \n\x08segments\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12!\n\x19max_segment_element_count\x18\x03 \x01(\x04\x12\x18\n\x10max_segment_size\x18\x04 \x01(\x04\x12\x1e\n\x16should_delay_archiving\x18\x05 \x01(\x08\x12\"\n\x1a\x64\x65layed_archiving_priority\x18\x06 \x01(\r\x12$\n\x1cstore_outside_object_archive\x18\x07 \x01(\x08\x12\x1b\n\x13\x65stimated_byte_size\x18\x08 \x01(\x04\"8\n\x10LargeNumberArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"8\n\x10LargeStringArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"<\n\x14LargeLazyObjectArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"8\n\x10LargeObjectArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"6\n\x0eLargeUUIDArray\x12$\n\x0blarge_array\x18\x01 \x01(\x0b\x32\x0f.TSP.LargeArray\"N\n\x1fStringToObjectDictionaryElement\x12\x0b\n\x03key\x18\x01 \x02(\t\x12\x1e\n\x06object\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\"u\n\x16LargeDictionarySegment\x12\x1e\n\x16should_delay_archiving\x18\x01 \x01(\x08\x12\"\n\x1a\x64\x65layed_archiving_priority\x18\x02 \x01(\r\x12\x17\n\x0fpackage_locator\x18\x03 \x01(\t\"\x9d\x01\n$LargeStringToObjectDictionarySegment\x12=\n\x18large_dictionary_segment\x18\x01 \x01(\x0b\x32\x1b.TSP.LargeDictionarySegment\x12\x36\n\x08\x65lements\x18\x02 \x03(\x0b\x32$.TSP.StringToObjectDictionaryElement\"\x84\x02\n\x0fLargeDictionary\x12\x1a\n\x06ranges\x18\x01 \x03(\x0b\x32\n.TSP.Range\x12 \n\x08segments\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12 \n\x18max_segment_object_count\x18\x04 \x01(\x04\x12\x18\n\x10max_segment_size\x18\x05 \x01(\x04\x12\x1e\n\x16should_delay_archiving\x18\x06 \x01(\x08\x12\"\n\x1a\x64\x65layed_archiving_priority\x18\x07 \x01(\r\x12$\n\x1cstore_outside_object_archive\x18\x08 \x01(\x08\"O\n\x1dLargeStringToObjectDictionary\x12.\n\x10large_dictionary\x18\x01 \x01(\x0b\x32\x14.TSP.LargeDictionary')
)



_COLOR_COLORMODEL = _descriptor.EnumDescriptor(
  name='ColorModel',
  full_name='TSP.Color.ColorModel',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='rgb', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='cmyk', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='white', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=674,
  serialized_end=716,
)
_sym_db.RegisterEnumDescriptor(_COLOR_COLORMODEL)

_COLOR_RGBCOLORSPACE = _descriptor.EnumDescriptor(
  name='RGBColorSpace',
  full_name='TSP.Color.RGBColorSpace',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='srgb', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='p3', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=718,
  serialized_end=751,
)
_sym_db.RegisterEnumDescriptor(_COLOR_RGBCOLORSPACE)

_PATH_ELEMENTTYPE = _descriptor.EnumDescriptor(
  name='ElementType',
  full_name='TSP.Path.ElementType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='moveTo', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='lineTo', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='quadCurveTo', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='curveTo', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='closeSubpath', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=875,
  serialized_end=960,
)
_sym_db.RegisterEnumDescriptor(_PATH_ELEMENTTYPE)


_REFERENCE = _descriptor.Descriptor(
  name='Reference',
  full_name='TSP.Reference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.Reference.identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_type', full_name='TSP.Reference.deprecated_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_is_external', full_name='TSP.Reference.deprecated_is_external', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26,
  serialized_end=114,
)


_DATAREFERENCE = _descriptor.Descriptor(
  name='DataReference',
  full_name='TSP.DataReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.DataReference.identifier', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=151,
)


_SPARSEREFERENCEARRAY_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSP.SparseReferenceArray.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TSP.SparseReferenceArray.Entry.index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference', full_name='TSP.SparseReferenceArray.Entry.reference', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=300,
)

_SPARSEREFERENCEARRAY = _descriptor.Descriptor(
  name='SparseReferenceArray',
  full_name='TSP.SparseReferenceArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='TSP.SparseReferenceArray.count', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSP.SparseReferenceArray.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPARSEREFERENCEARRAY_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=300,
)


_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='TSP.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='TSP.Point.x', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='TSP.Point.y', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=331,
)


_SIZE = _descriptor.Descriptor(
  name='Size',
  full_name='TSP.Size',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='width', full_name='TSP.Size.width', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='TSP.Size.height', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=370,
)


_RANGE = _descriptor.Descriptor(
  name='Range',
  full_name='TSP.Range',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='TSP.Range.location', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='length', full_name='TSP.Range.length', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=372,
  serialized_end=413,
)


_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='TSP.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='TSP.Date.seconds', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=438,
)


_INDEXSET = _descriptor.Descriptor(
  name='IndexSet',
  full_name='TSP.IndexSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranges', full_name='TSP.IndexSet.ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=478,
)


_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='TSP.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='TSP.Color.model', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='r', full_name='TSP.Color.r', index=1,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='g', full_name='TSP.Color.g', index=2,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='b', full_name='TSP.Color.b', index=3,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rgbspace', full_name='TSP.Color.rgbspace', index=4,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='a', full_name='TSP.Color.a', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='c', full_name='TSP.Color.c', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='m', full_name='TSP.Color.m', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='y', full_name='TSP.Color.y', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='k', full_name='TSP.Color.k', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='w', full_name='TSP.Color.w', index=10,
      number=11, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COLOR_COLORMODEL,
    _COLOR_RGBCOLORSPACE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=481,
  serialized_end=751,
)


_PATH_ELEMENT = _descriptor.Descriptor(
  name='Element',
  full_name='TSP.Path.Element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='TSP.Path.Element.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='points', full_name='TSP.Path.Element.points', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=799,
  serialized_end=873,
)

_PATH = _descriptor.Descriptor(
  name='Path',
  full_name='TSP.Path',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.Path.elements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PATH_ELEMENT, ],
  enum_types=[
    _PATH_ELEMENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=754,
  serialized_end=960,
)


_REFERENCEDICTIONARY_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSP.ReferenceDictionary.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='TSP.ReferenceDictionary.Entry.key', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='TSP.ReferenceDictionary.Entry.value', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1035,
  serialized_end=1102,
)

_REFERENCEDICTIONARY = _descriptor.Descriptor(
  name='ReferenceDictionary',
  full_name='TSP.ReferenceDictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSP.ReferenceDictionary.entries', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_REFERENCEDICTIONARY_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1102,
)


_UUID = _descriptor.Descriptor(
  name='UUID',
  full_name='TSP.UUID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lower', full_name='TSP.UUID.lower', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upper', full_name='TSP.UUID.upper', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1140,
)


_CFUUIDARCHIVE = _descriptor.Descriptor(
  name='CFUUIDArchive',
  full_name='TSP.CFUUIDArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid_bytes', full_name='TSP.CFUUIDArchive.uuid_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_w0', full_name='TSP.CFUUIDArchive.uuid_w0', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_w1', full_name='TSP.CFUUIDArchive.uuid_w1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_w2', full_name='TSP.CFUUIDArchive.uuid_w2', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_w3', full_name='TSP.CFUUIDArchive.uuid_w3', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1142,
  serialized_end=1245,
)


_UUIDSETARCHIVE = _descriptor.Descriptor(
  name='UUIDSetArchive',
  full_name='TSP.UUIDSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uids', full_name='TSP.UUIDSetArchive.uids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1247,
  serialized_end=1288,
)


_UUIDMAPARCHIVE = _descriptor.Descriptor(
  name='UUIDMapArchive',
  full_name='TSP.UUIDMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='TSP.UUIDMapArchive.source', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='TSP.UUIDMapArchive.target', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1290,
  serialized_end=1360,
)


_UUIDMULTIMAPARCHIVE = _descriptor.Descriptor(
  name='UUIDMultiMapArchive',
  full_name='TSP.UUIDMultiMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='TSP.UUIDMultiMapArchive.source', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='TSP.UUIDMultiMapArchive.target', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1362,
  serialized_end=1437,
)


_UUIDCOORDARCHIVE = _descriptor.Descriptor(
  name='UUIDCoordArchive',
  full_name='TSP.UUIDCoordArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_uid', full_name='TSP.UUIDCoordArchive.row_uid', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_uid', full_name='TSP.UUIDCoordArchive.column_uid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1439,
  serialized_end=1516,
)


_UUIDRECTARCHIVE = _descriptor.Descriptor(
  name='UUIDRectArchive',
  full_name='TSP.UUIDRectArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_uids', full_name='TSP.UUIDRectArchive.column_uids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_uids', full_name='TSP.UUIDRectArchive.row_uids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1518,
  serialized_end=1596,
)


_SPARSEUUIDARRAY_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSP.SparseUUIDArray.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TSP.SparseUUIDArray.Entry.index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSP.SparseUUIDArray.Entry.uuid', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1677,
  serialized_end=1724,
)

_SPARSEUUIDARRAY = _descriptor.Descriptor(
  name='SparseUUIDArray',
  full_name='TSP.SparseUUIDArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='TSP.SparseUUIDArray.count', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSP.SparseUUIDArray.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPARSEUUIDARRAY_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1598,
  serialized_end=1724,
)


_UUIDPATH = _descriptor.Descriptor(
  name='UUIDPath',
  full_name='TSP.UUIDPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='TSP.UUIDPath.uuids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1726,
  serialized_end=1762,
)


_SPARSEUUIDPATHARRAY_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='TSP.SparseUUIDPathArray.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TSP.SparseUUIDPathArray.Entry.index', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid_path', full_name='TSP.SparseUUIDPathArray.Entry.uuid_path', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=1908,
)

_SPARSEUUIDPATHARRAY = _descriptor.Descriptor(
  name='SparseUUIDPathArray',
  full_name='TSP.SparseUUIDPathArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='TSP.SparseUUIDPathArray.count', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entries', full_name='TSP.SparseUUIDPathArray.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SPARSEUUIDPATHARRAY_ENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1765,
  serialized_end=1908,
)


_PASTEBOARDOBJECT = _descriptor.Descriptor(
  name='PasteboardObject',
  full_name='TSP.PasteboardObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stylesheet', full_name='TSP.PasteboardObject.stylesheet', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='drawables', full_name='TSP.PasteboardObject.drawables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='styles', full_name='TSP.PasteboardObject.styles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wp_storage', full_name='TSP.PasteboardObject.wp_storage', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='guide_storage', full_name='TSP.PasteboardObject.guide_storage', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_native_object', full_name='TSP.PasteboardObject.app_native_object', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_text_primary', full_name='TSP.PasteboardObject.is_text_primary', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_smart', full_name='TSP.PasteboardObject.is_smart', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='presets', full_name='TSP.PasteboardObject.presets', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_level_objects', full_name='TSP.PasteboardObject.top_level_objects', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='native_content_description', full_name='TSP.PasteboardObject.native_content_description', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1911,
  serialized_end=2321,
)


_OBJECTCOLLECTION = _descriptor.Descriptor(
  name='ObjectCollection',
  full_name='TSP.ObjectCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='objects', full_name='TSP.ObjectCollection.objects', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2374,
)


_OBJECTCONTAINER = _descriptor.Descriptor(
  name='ObjectContainer',
  full_name='TSP.ObjectContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSP.ObjectContainer.identifier', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objects', full_name='TSP.ObjectContainer.objects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=2446,
)


_DATAATTRIBUTES = _descriptor.Descriptor(
  name='DataAttributes',
  full_name='TSP.DataAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=True,
  syntax='proto2',
  extension_ranges=[(100, 536870912), ],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2474,
)


_LARGEARRAYSEGMENT = _descriptor.Descriptor(
  name='LargeArraySegment',
  full_name='TSP.LargeArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='should_delay_archiving', full_name='TSP.LargeArraySegment.should_delay_archiving', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delayed_archiving_priority', full_name='TSP.LargeArraySegment.delayed_archiving_priority', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_locator', full_name='TSP.LargeArraySegment.package_locator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2476,
  serialized_end=2588,
)


_LARGENUMBERARRAYSEGMENT = _descriptor.Descriptor(
  name='LargeNumberArraySegment',
  full_name='TSP.LargeNumberArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TSP.LargeNumberArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.LargeNumberArraySegment.elements', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2590,
  serialized_end=2686,
)


_LARGESTRINGARRAYSEGMENT_OPTIONALELEMENT = _descriptor.Descriptor(
  name='OptionalElement',
  full_name='TSP.LargeStringArraySegment.OptionalElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='element', full_name='TSP.LargeStringArraySegment.OptionalElement.element', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2833,
  serialized_end=2867,
)

_LARGESTRINGARRAYSEGMENT = _descriptor.Descriptor(
  name='LargeStringArraySegment',
  full_name='TSP.LargeStringArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TSP.LargeStringArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.LargeStringArraySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_LARGESTRINGARRAYSEGMENT_OPTIONALELEMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2689,
  serialized_end=2867,
)


_LARGEUUIDARRAYSEGMENT = _descriptor.Descriptor(
  name='LargeUUIDArraySegment',
  full_name='TSP.LargeUUIDArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TSP.LargeUUIDArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.LargeUUIDArraySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2869,
  serialized_end=2974,
)


_LARGELAZYOBJECTARRAYSEGMENT = _descriptor.Descriptor(
  name='LargeLazyObjectArraySegment',
  full_name='TSP.LargeLazyObjectArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TSP.LargeLazyObjectArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.LargeLazyObjectArraySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2976,
  serialized_end=3092,
)


_LARGEOBJECTARRAYSEGMENT = _descriptor.Descriptor(
  name='LargeObjectArraySegment',
  full_name='TSP.LargeObjectArraySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array_segment', full_name='TSP.LargeObjectArraySegment.large_array_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.LargeObjectArraySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3094,
  serialized_end=3206,
)


_LARGEARRAY = _descriptor.Descriptor(
  name='LargeArray',
  full_name='TSP.LargeArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranges', full_name='TSP.LargeArray.ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='TSP.LargeArray.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_segment_element_count', full_name='TSP.LargeArray.max_segment_element_count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_segment_size', full_name='TSP.LargeArray.max_segment_size', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_delay_archiving', full_name='TSP.LargeArray.should_delay_archiving', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delayed_archiving_priority', full_name='TSP.LargeArray.delayed_archiving_priority', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_outside_object_archive', full_name='TSP.LargeArray.store_outside_object_archive', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='estimated_byte_size', full_name='TSP.LargeArray.estimated_byte_size', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3209,
  serialized_end=3479,
)


_LARGENUMBERARRAY = _descriptor.Descriptor(
  name='LargeNumberArray',
  full_name='TSP.LargeNumberArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TSP.LargeNumberArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3481,
  serialized_end=3537,
)


_LARGESTRINGARRAY = _descriptor.Descriptor(
  name='LargeStringArray',
  full_name='TSP.LargeStringArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TSP.LargeStringArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3539,
  serialized_end=3595,
)


_LARGELAZYOBJECTARRAY = _descriptor.Descriptor(
  name='LargeLazyObjectArray',
  full_name='TSP.LargeLazyObjectArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TSP.LargeLazyObjectArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3597,
  serialized_end=3657,
)


_LARGEOBJECTARRAY = _descriptor.Descriptor(
  name='LargeObjectArray',
  full_name='TSP.LargeObjectArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TSP.LargeObjectArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3659,
  serialized_end=3715,
)


_LARGEUUIDARRAY = _descriptor.Descriptor(
  name='LargeUUIDArray',
  full_name='TSP.LargeUUIDArray',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_array', full_name='TSP.LargeUUIDArray.large_array', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3717,
  serialized_end=3771,
)


_STRINGTOOBJECTDICTIONARYELEMENT = _descriptor.Descriptor(
  name='StringToObjectDictionaryElement',
  full_name='TSP.StringToObjectDictionaryElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='TSP.StringToObjectDictionaryElement.key', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='object', full_name='TSP.StringToObjectDictionaryElement.object', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3773,
  serialized_end=3851,
)


_LARGEDICTIONARYSEGMENT = _descriptor.Descriptor(
  name='LargeDictionarySegment',
  full_name='TSP.LargeDictionarySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='should_delay_archiving', full_name='TSP.LargeDictionarySegment.should_delay_archiving', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delayed_archiving_priority', full_name='TSP.LargeDictionarySegment.delayed_archiving_priority', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='package_locator', full_name='TSP.LargeDictionarySegment.package_locator', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3853,
  serialized_end=3970,
)


_LARGESTRINGTOOBJECTDICTIONARYSEGMENT = _descriptor.Descriptor(
  name='LargeStringToObjectDictionarySegment',
  full_name='TSP.LargeStringToObjectDictionarySegment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_dictionary_segment', full_name='TSP.LargeStringToObjectDictionarySegment.large_dictionary_segment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='elements', full_name='TSP.LargeStringToObjectDictionarySegment.elements', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3973,
  serialized_end=4130,
)


_LARGEDICTIONARY = _descriptor.Descriptor(
  name='LargeDictionary',
  full_name='TSP.LargeDictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ranges', full_name='TSP.LargeDictionary.ranges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='segments', full_name='TSP.LargeDictionary.segments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='TSP.LargeDictionary.count', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_segment_object_count', full_name='TSP.LargeDictionary.max_segment_object_count', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_segment_size', full_name='TSP.LargeDictionary.max_segment_size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_delay_archiving', full_name='TSP.LargeDictionary.should_delay_archiving', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delayed_archiving_priority', full_name='TSP.LargeDictionary.delayed_archiving_priority', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='store_outside_object_archive', full_name='TSP.LargeDictionary.store_outside_object_archive', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4133,
  serialized_end=4393,
)


_LARGESTRINGTOOBJECTDICTIONARY = _descriptor.Descriptor(
  name='LargeStringToObjectDictionary',
  full_name='TSP.LargeStringToObjectDictionary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='large_dictionary', full_name='TSP.LargeStringToObjectDictionary.large_dictionary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4395,
  serialized_end=4474,
)

_SPARSEREFERENCEARRAY_ENTRY.fields_by_name['reference'].message_type = _REFERENCE
_SPARSEREFERENCEARRAY_ENTRY.containing_type = _SPARSEREFERENCEARRAY
_SPARSEREFERENCEARRAY.fields_by_name['entries'].message_type = _SPARSEREFERENCEARRAY_ENTRY
_INDEXSET.fields_by_name['ranges'].message_type = _RANGE
_COLOR.fields_by_name['model'].enum_type = _COLOR_COLORMODEL
_COLOR.fields_by_name['rgbspace'].enum_type = _COLOR_RGBCOLORSPACE
_COLOR_COLORMODEL.containing_type = _COLOR
_COLOR_RGBCOLORSPACE.containing_type = _COLOR
_PATH_ELEMENT.fields_by_name['type'].enum_type = _PATH_ELEMENTTYPE
_PATH_ELEMENT.fields_by_name['points'].message_type = _POINT
_PATH_ELEMENT.containing_type = _PATH
_PATH.fields_by_name['elements'].message_type = _PATH_ELEMENT
_PATH_ELEMENTTYPE.containing_type = _PATH
_REFERENCEDICTIONARY_ENTRY.fields_by_name['key'].message_type = _REFERENCE
_REFERENCEDICTIONARY_ENTRY.fields_by_name['value'].message_type = _REFERENCE
_REFERENCEDICTIONARY_ENTRY.containing_type = _REFERENCEDICTIONARY
_REFERENCEDICTIONARY.fields_by_name['entries'].message_type = _REFERENCEDICTIONARY_ENTRY
_UUIDSETARCHIVE.fields_by_name['uids'].message_type = _UUID
_UUIDMAPARCHIVE.fields_by_name['source'].message_type = _UUID
_UUIDMAPARCHIVE.fields_by_name['target'].message_type = _UUID
_UUIDMULTIMAPARCHIVE.fields_by_name['source'].message_type = _UUID
_UUIDMULTIMAPARCHIVE.fields_by_name['target'].message_type = _UUID
_UUIDCOORDARCHIVE.fields_by_name['row_uid'].message_type = _UUID
_UUIDCOORDARCHIVE.fields_by_name['column_uid'].message_type = _UUID
_UUIDRECTARCHIVE.fields_by_name['column_uids'].message_type = _UUID
_UUIDRECTARCHIVE.fields_by_name['row_uids'].message_type = _UUID
_SPARSEUUIDARRAY_ENTRY.fields_by_name['uuid'].message_type = _UUID
_SPARSEUUIDARRAY_ENTRY.containing_type = _SPARSEUUIDARRAY
_SPARSEUUIDARRAY.fields_by_name['entries'].message_type = _SPARSEUUIDARRAY_ENTRY
_UUIDPATH.fields_by_name['uuids'].message_type = _UUID
_SPARSEUUIDPATHARRAY_ENTRY.fields_by_name['uuid_path'].message_type = _UUIDPATH
_SPARSEUUIDPATHARRAY_ENTRY.containing_type = _SPARSEUUIDPATHARRAY
_SPARSEUUIDPATHARRAY.fields_by_name['entries'].message_type = _SPARSEUUIDPATHARRAY_ENTRY
_PASTEBOARDOBJECT.fields_by_name['stylesheet'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['drawables'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['styles'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['wp_storage'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['guide_storage'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['app_native_object'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['presets'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['top_level_objects'].message_type = _REFERENCE
_PASTEBOARDOBJECT.fields_by_name['native_content_description'].message_type = _REFERENCE
_OBJECTCOLLECTION.fields_by_name['objects'].message_type = _REFERENCE
_OBJECTCONTAINER.fields_by_name['objects'].message_type = _REFERENCE
_LARGENUMBERARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = _LARGEARRAYSEGMENT
_LARGESTRINGARRAYSEGMENT_OPTIONALELEMENT.containing_type = _LARGESTRINGARRAYSEGMENT
_LARGESTRINGARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = _LARGEARRAYSEGMENT
_LARGESTRINGARRAYSEGMENT.fields_by_name['elements'].message_type = _LARGESTRINGARRAYSEGMENT_OPTIONALELEMENT
_LARGEUUIDARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = _LARGEARRAYSEGMENT
_LARGEUUIDARRAYSEGMENT.fields_by_name['elements'].message_type = _UUID
_LARGELAZYOBJECTARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = _LARGEARRAYSEGMENT
_LARGELAZYOBJECTARRAYSEGMENT.fields_by_name['elements'].message_type = _REFERENCE
_LARGEOBJECTARRAYSEGMENT.fields_by_name['large_array_segment'].message_type = _LARGEARRAYSEGMENT
_LARGEOBJECTARRAYSEGMENT.fields_by_name['elements'].message_type = _REFERENCE
_LARGEARRAY.fields_by_name['ranges'].message_type = _RANGE
_LARGEARRAY.fields_by_name['segments'].message_type = _REFERENCE
_LARGENUMBERARRAY.fields_by_name['large_array'].message_type = _LARGEARRAY
_LARGESTRINGARRAY.fields_by_name['large_array'].message_type = _LARGEARRAY
_LARGELAZYOBJECTARRAY.fields_by_name['large_array'].message_type = _LARGEARRAY
_LARGEOBJECTARRAY.fields_by_name['large_array'].message_type = _LARGEARRAY
_LARGEUUIDARRAY.fields_by_name['large_array'].message_type = _LARGEARRAY
_STRINGTOOBJECTDICTIONARYELEMENT.fields_by_name['object'].message_type = _REFERENCE
_LARGESTRINGTOOBJECTDICTIONARYSEGMENT.fields_by_name['large_dictionary_segment'].message_type = _LARGEDICTIONARYSEGMENT
_LARGESTRINGTOOBJECTDICTIONARYSEGMENT.fields_by_name['elements'].message_type = _STRINGTOOBJECTDICTIONARYELEMENT
_LARGEDICTIONARY.fields_by_name['ranges'].message_type = _RANGE
_LARGEDICTIONARY.fields_by_name['segments'].message_type = _REFERENCE
_LARGESTRINGTOOBJECTDICTIONARY.fields_by_name['large_dictionary'].message_type = _LARGEDICTIONARY
DESCRIPTOR.message_types_by_name['Reference'] = _REFERENCE
DESCRIPTOR.message_types_by_name['DataReference'] = _DATAREFERENCE
DESCRIPTOR.message_types_by_name['SparseReferenceArray'] = _SPARSEREFERENCEARRAY
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['Size'] = _SIZE
DESCRIPTOR.message_types_by_name['Range'] = _RANGE
DESCRIPTOR.message_types_by_name['Date'] = _DATE
DESCRIPTOR.message_types_by_name['IndexSet'] = _INDEXSET
DESCRIPTOR.message_types_by_name['Color'] = _COLOR
DESCRIPTOR.message_types_by_name['Path'] = _PATH
DESCRIPTOR.message_types_by_name['ReferenceDictionary'] = _REFERENCEDICTIONARY
DESCRIPTOR.message_types_by_name['UUID'] = _UUID
DESCRIPTOR.message_types_by_name['CFUUIDArchive'] = _CFUUIDARCHIVE
DESCRIPTOR.message_types_by_name['UUIDSetArchive'] = _UUIDSETARCHIVE
DESCRIPTOR.message_types_by_name['UUIDMapArchive'] = _UUIDMAPARCHIVE
DESCRIPTOR.message_types_by_name['UUIDMultiMapArchive'] = _UUIDMULTIMAPARCHIVE
DESCRIPTOR.message_types_by_name['UUIDCoordArchive'] = _UUIDCOORDARCHIVE
DESCRIPTOR.message_types_by_name['UUIDRectArchive'] = _UUIDRECTARCHIVE
DESCRIPTOR.message_types_by_name['SparseUUIDArray'] = _SPARSEUUIDARRAY
DESCRIPTOR.message_types_by_name['UUIDPath'] = _UUIDPATH
DESCRIPTOR.message_types_by_name['SparseUUIDPathArray'] = _SPARSEUUIDPATHARRAY
DESCRIPTOR.message_types_by_name['PasteboardObject'] = _PASTEBOARDOBJECT
DESCRIPTOR.message_types_by_name['ObjectCollection'] = _OBJECTCOLLECTION
DESCRIPTOR.message_types_by_name['ObjectContainer'] = _OBJECTCONTAINER
DESCRIPTOR.message_types_by_name['DataAttributes'] = _DATAATTRIBUTES
DESCRIPTOR.message_types_by_name['LargeArraySegment'] = _LARGEARRAYSEGMENT
DESCRIPTOR.message_types_by_name['LargeNumberArraySegment'] = _LARGENUMBERARRAYSEGMENT
DESCRIPTOR.message_types_by_name['LargeStringArraySegment'] = _LARGESTRINGARRAYSEGMENT
DESCRIPTOR.message_types_by_name['LargeUUIDArraySegment'] = _LARGEUUIDARRAYSEGMENT
DESCRIPTOR.message_types_by_name['LargeLazyObjectArraySegment'] = _LARGELAZYOBJECTARRAYSEGMENT
DESCRIPTOR.message_types_by_name['LargeObjectArraySegment'] = _LARGEOBJECTARRAYSEGMENT
DESCRIPTOR.message_types_by_name['LargeArray'] = _LARGEARRAY
DESCRIPTOR.message_types_by_name['LargeNumberArray'] = _LARGENUMBERARRAY
DESCRIPTOR.message_types_by_name['LargeStringArray'] = _LARGESTRINGARRAY
DESCRIPTOR.message_types_by_name['LargeLazyObjectArray'] = _LARGELAZYOBJECTARRAY
DESCRIPTOR.message_types_by_name['LargeObjectArray'] = _LARGEOBJECTARRAY
DESCRIPTOR.message_types_by_name['LargeUUIDArray'] = _LARGEUUIDARRAY
DESCRIPTOR.message_types_by_name['StringToObjectDictionaryElement'] = _STRINGTOOBJECTDICTIONARYELEMENT
DESCRIPTOR.message_types_by_name['LargeDictionarySegment'] = _LARGEDICTIONARYSEGMENT
DESCRIPTOR.message_types_by_name['LargeStringToObjectDictionarySegment'] = _LARGESTRINGTOOBJECTDICTIONARYSEGMENT
DESCRIPTOR.message_types_by_name['LargeDictionary'] = _LARGEDICTIONARY
DESCRIPTOR.message_types_by_name['LargeStringToObjectDictionary'] = _LARGESTRINGTOOBJECTDICTIONARY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reference = _reflection.GeneratedProtocolMessageType('Reference', (_message.Message,), dict(
  DESCRIPTOR = _REFERENCE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Reference)
  ))
_sym_db.RegisterMessage(Reference)

DataReference = _reflection.GeneratedProtocolMessageType('DataReference', (_message.Message,), dict(
  DESCRIPTOR = _DATAREFERENCE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DataReference)
  ))
_sym_db.RegisterMessage(DataReference)

SparseReferenceArray = _reflection.GeneratedProtocolMessageType('SparseReferenceArray', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _SPARSEREFERENCEARRAY_ENTRY,
    __module__ = 'TSPMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.SparseReferenceArray.Entry)
    ))
  ,
  DESCRIPTOR = _SPARSEREFERENCEARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.SparseReferenceArray)
  ))
_sym_db.RegisterMessage(SparseReferenceArray)
_sym_db.RegisterMessage(SparseReferenceArray.Entry)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), dict(
  DESCRIPTOR = _POINT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Point)
  ))
_sym_db.RegisterMessage(Point)

Size = _reflection.GeneratedProtocolMessageType('Size', (_message.Message,), dict(
  DESCRIPTOR = _SIZE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Size)
  ))
_sym_db.RegisterMessage(Size)

Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), dict(
  DESCRIPTOR = _RANGE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Range)
  ))
_sym_db.RegisterMessage(Range)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), dict(
  DESCRIPTOR = _DATE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Date)
  ))
_sym_db.RegisterMessage(Date)

IndexSet = _reflection.GeneratedProtocolMessageType('IndexSet', (_message.Message,), dict(
  DESCRIPTOR = _INDEXSET,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.IndexSet)
  ))
_sym_db.RegisterMessage(IndexSet)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), dict(
  DESCRIPTOR = _COLOR,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Color)
  ))
_sym_db.RegisterMessage(Color)

Path = _reflection.GeneratedProtocolMessageType('Path', (_message.Message,), dict(

  Element = _reflection.GeneratedProtocolMessageType('Element', (_message.Message,), dict(
    DESCRIPTOR = _PATH_ELEMENT,
    __module__ = 'TSPMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.Path.Element)
    ))
  ,
  DESCRIPTOR = _PATH,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.Path)
  ))
_sym_db.RegisterMessage(Path)
_sym_db.RegisterMessage(Path.Element)

ReferenceDictionary = _reflection.GeneratedProtocolMessageType('ReferenceDictionary', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _REFERENCEDICTIONARY_ENTRY,
    __module__ = 'TSPMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.ReferenceDictionary.Entry)
    ))
  ,
  DESCRIPTOR = _REFERENCEDICTIONARY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ReferenceDictionary)
  ))
_sym_db.RegisterMessage(ReferenceDictionary)
_sym_db.RegisterMessage(ReferenceDictionary.Entry)

UUID = _reflection.GeneratedProtocolMessageType('UUID', (_message.Message,), dict(
  DESCRIPTOR = _UUID,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUID)
  ))
_sym_db.RegisterMessage(UUID)

CFUUIDArchive = _reflection.GeneratedProtocolMessageType('CFUUIDArchive', (_message.Message,), dict(
  DESCRIPTOR = _CFUUIDARCHIVE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.CFUUIDArchive)
  ))
_sym_db.RegisterMessage(CFUUIDArchive)

UUIDSetArchive = _reflection.GeneratedProtocolMessageType('UUIDSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _UUIDSETARCHIVE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUIDSetArchive)
  ))
_sym_db.RegisterMessage(UUIDSetArchive)

UUIDMapArchive = _reflection.GeneratedProtocolMessageType('UUIDMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _UUIDMAPARCHIVE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUIDMapArchive)
  ))
_sym_db.RegisterMessage(UUIDMapArchive)

UUIDMultiMapArchive = _reflection.GeneratedProtocolMessageType('UUIDMultiMapArchive', (_message.Message,), dict(
  DESCRIPTOR = _UUIDMULTIMAPARCHIVE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUIDMultiMapArchive)
  ))
_sym_db.RegisterMessage(UUIDMultiMapArchive)

UUIDCoordArchive = _reflection.GeneratedProtocolMessageType('UUIDCoordArchive', (_message.Message,), dict(
  DESCRIPTOR = _UUIDCOORDARCHIVE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUIDCoordArchive)
  ))
_sym_db.RegisterMessage(UUIDCoordArchive)

UUIDRectArchive = _reflection.GeneratedProtocolMessageType('UUIDRectArchive', (_message.Message,), dict(
  DESCRIPTOR = _UUIDRECTARCHIVE,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUIDRectArchive)
  ))
_sym_db.RegisterMessage(UUIDRectArchive)

SparseUUIDArray = _reflection.GeneratedProtocolMessageType('SparseUUIDArray', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _SPARSEUUIDARRAY_ENTRY,
    __module__ = 'TSPMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.SparseUUIDArray.Entry)
    ))
  ,
  DESCRIPTOR = _SPARSEUUIDARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.SparseUUIDArray)
  ))
_sym_db.RegisterMessage(SparseUUIDArray)
_sym_db.RegisterMessage(SparseUUIDArray.Entry)

UUIDPath = _reflection.GeneratedProtocolMessageType('UUIDPath', (_message.Message,), dict(
  DESCRIPTOR = _UUIDPATH,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.UUIDPath)
  ))
_sym_db.RegisterMessage(UUIDPath)

SparseUUIDPathArray = _reflection.GeneratedProtocolMessageType('SparseUUIDPathArray', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _SPARSEUUIDPATHARRAY_ENTRY,
    __module__ = 'TSPMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.SparseUUIDPathArray.Entry)
    ))
  ,
  DESCRIPTOR = _SPARSEUUIDPATHARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.SparseUUIDPathArray)
  ))
_sym_db.RegisterMessage(SparseUUIDPathArray)
_sym_db.RegisterMessage(SparseUUIDPathArray.Entry)

PasteboardObject = _reflection.GeneratedProtocolMessageType('PasteboardObject', (_message.Message,), dict(
  DESCRIPTOR = _PASTEBOARDOBJECT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.PasteboardObject)
  ))
_sym_db.RegisterMessage(PasteboardObject)

ObjectCollection = _reflection.GeneratedProtocolMessageType('ObjectCollection', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTCOLLECTION,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ObjectCollection)
  ))
_sym_db.RegisterMessage(ObjectCollection)

ObjectContainer = _reflection.GeneratedProtocolMessageType('ObjectContainer', (_message.Message,), dict(
  DESCRIPTOR = _OBJECTCONTAINER,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.ObjectContainer)
  ))
_sym_db.RegisterMessage(ObjectContainer)

DataAttributes = _reflection.GeneratedProtocolMessageType('DataAttributes', (_message.Message,), dict(
  DESCRIPTOR = _DATAATTRIBUTES,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.DataAttributes)
  ))
_sym_db.RegisterMessage(DataAttributes)

LargeArraySegment = _reflection.GeneratedProtocolMessageType('LargeArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGEARRAYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeArraySegment)
  ))
_sym_db.RegisterMessage(LargeArraySegment)

LargeNumberArraySegment = _reflection.GeneratedProtocolMessageType('LargeNumberArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGENUMBERARRAYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeNumberArraySegment)
  ))
_sym_db.RegisterMessage(LargeNumberArraySegment)

LargeStringArraySegment = _reflection.GeneratedProtocolMessageType('LargeStringArraySegment', (_message.Message,), dict(

  OptionalElement = _reflection.GeneratedProtocolMessageType('OptionalElement', (_message.Message,), dict(
    DESCRIPTOR = _LARGESTRINGARRAYSEGMENT_OPTIONALELEMENT,
    __module__ = 'TSPMessages_pb2'
    # @@protoc_insertion_point(class_scope:TSP.LargeStringArraySegment.OptionalElement)
    ))
  ,
  DESCRIPTOR = _LARGESTRINGARRAYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeStringArraySegment)
  ))
_sym_db.RegisterMessage(LargeStringArraySegment)
_sym_db.RegisterMessage(LargeStringArraySegment.OptionalElement)

LargeUUIDArraySegment = _reflection.GeneratedProtocolMessageType('LargeUUIDArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGEUUIDARRAYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeUUIDArraySegment)
  ))
_sym_db.RegisterMessage(LargeUUIDArraySegment)

LargeLazyObjectArraySegment = _reflection.GeneratedProtocolMessageType('LargeLazyObjectArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGELAZYOBJECTARRAYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeLazyObjectArraySegment)
  ))
_sym_db.RegisterMessage(LargeLazyObjectArraySegment)

LargeObjectArraySegment = _reflection.GeneratedProtocolMessageType('LargeObjectArraySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGEOBJECTARRAYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeObjectArraySegment)
  ))
_sym_db.RegisterMessage(LargeObjectArraySegment)

LargeArray = _reflection.GeneratedProtocolMessageType('LargeArray', (_message.Message,), dict(
  DESCRIPTOR = _LARGEARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeArray)
  ))
_sym_db.RegisterMessage(LargeArray)

LargeNumberArray = _reflection.GeneratedProtocolMessageType('LargeNumberArray', (_message.Message,), dict(
  DESCRIPTOR = _LARGENUMBERARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeNumberArray)
  ))
_sym_db.RegisterMessage(LargeNumberArray)

LargeStringArray = _reflection.GeneratedProtocolMessageType('LargeStringArray', (_message.Message,), dict(
  DESCRIPTOR = _LARGESTRINGARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeStringArray)
  ))
_sym_db.RegisterMessage(LargeStringArray)

LargeLazyObjectArray = _reflection.GeneratedProtocolMessageType('LargeLazyObjectArray', (_message.Message,), dict(
  DESCRIPTOR = _LARGELAZYOBJECTARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeLazyObjectArray)
  ))
_sym_db.RegisterMessage(LargeLazyObjectArray)

LargeObjectArray = _reflection.GeneratedProtocolMessageType('LargeObjectArray', (_message.Message,), dict(
  DESCRIPTOR = _LARGEOBJECTARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeObjectArray)
  ))
_sym_db.RegisterMessage(LargeObjectArray)

LargeUUIDArray = _reflection.GeneratedProtocolMessageType('LargeUUIDArray', (_message.Message,), dict(
  DESCRIPTOR = _LARGEUUIDARRAY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeUUIDArray)
  ))
_sym_db.RegisterMessage(LargeUUIDArray)

StringToObjectDictionaryElement = _reflection.GeneratedProtocolMessageType('StringToObjectDictionaryElement', (_message.Message,), dict(
  DESCRIPTOR = _STRINGTOOBJECTDICTIONARYELEMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.StringToObjectDictionaryElement)
  ))
_sym_db.RegisterMessage(StringToObjectDictionaryElement)

LargeDictionarySegment = _reflection.GeneratedProtocolMessageType('LargeDictionarySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGEDICTIONARYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeDictionarySegment)
  ))
_sym_db.RegisterMessage(LargeDictionarySegment)

LargeStringToObjectDictionarySegment = _reflection.GeneratedProtocolMessageType('LargeStringToObjectDictionarySegment', (_message.Message,), dict(
  DESCRIPTOR = _LARGESTRINGTOOBJECTDICTIONARYSEGMENT,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeStringToObjectDictionarySegment)
  ))
_sym_db.RegisterMessage(LargeStringToObjectDictionarySegment)

LargeDictionary = _reflection.GeneratedProtocolMessageType('LargeDictionary', (_message.Message,), dict(
  DESCRIPTOR = _LARGEDICTIONARY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeDictionary)
  ))
_sym_db.RegisterMessage(LargeDictionary)

LargeStringToObjectDictionary = _reflection.GeneratedProtocolMessageType('LargeStringToObjectDictionary', (_message.Message,), dict(
  DESCRIPTOR = _LARGESTRINGTOOBJECTDICTIONARY,
  __module__ = 'TSPMessages_pb2'
  # @@protoc_insertion_point(class_scope:TSP.LargeStringToObjectDictionary)
  ))
_sym_db.RegisterMessage(LargeStringToObjectDictionary)


# @@protoc_insertion_point(module_scope)
